# dapodix

[![dapodix - PyPi](https://img.shields.io/pypi/v/dapodix)](https://pypi.org/project/dapodix/)
[![Download](https://img.shields.io/badge/Download-Unduh-brightgreen)](https://github.com/hexatester/dapodix/archive/master.zip)
[![Donate DANA](https://img.shields.io/badge/Donasi-Saweria-blue)](https://saweria.co/hexatester)
[![Tutorial](https://img.shields.io/badge/Tutorial-Penggunaan-informational)](https://github.com/hexatester/dapodix/wiki)
[![Group Telegram](https://img.shields.io/badge/Telegram-Group-blue.svg)](https://t.me/dapodik_2021)
[![codecov](https://codecov.io/gh/hexatester/dapodix/branch/master/graph/badge.svg)](https://codecov.io/gh/hexatester/dapodix)
[![LISENSI](https://img.shields.io/github/license/hexatester/dapodix)](https://github.com/hexatester/dapodix/blob/master/LISENSI)

Alat bantu aplikasi dapodik.

## Install

Pastikan minimal [python versi 3.7](https://www.python.org/downloads/release/python-3711/) terinstall,
kemudian jalankan perintah di bawah dalam Command Prompt atau Powershell (di Windows + X):

```bash
pip install --upgrade dapodix
```

## Fitur yang akan datang

- Download data ke Excel
- Petunjuk validasi
- Bulk update dari Excel

## Legal / Hukum

Kode ini sama sekali tidak berafiliasi dengan, diizinkan, dipelihara, disponsori atau didukung oleh [Kemdikbud](https://kemdikbud.go.id/) atau afiliasi atau anak organisasinya. Ini adalah perangkat lunak yang independen dan tidak resmi. _Gunakan dengan risiko Anda sendiri._
